===============
django-backupdb
===============

Management commands for automatically backing up and restoring all databases
defined in ``settings.DATABASES``.

License
-------

Please take a moment to read the license specified in the ``LICENSE`` file.
